﻿using MindFusion.Charting;
using MindFusion.Drawing;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Xamarin.Forms;

namespace Interactivity
{
	// Learn more about making custom code visible in the Xamarin.Forms previewer
	// by visiting https://aka.ms/xamarinforms-previewer
	[DesignTimeVisible(false)]
	public partial class MainPage : ContentPage
	{
		public MainPage()
		{
			InitializeComponent();
            // BarChart
            barChart.Series = GetSeriesCollection();
            barChart.Title = "Bar Chart";
            barChart.BackgroundColor = Colors.WhiteSmoke;

            barChart.AllowZoom = true;
            barChart.AllowPan = true;
            barChart.AllowMoveLegend = true;

            barChart.XAxis.Title = "";
            barChart.XAxis.MinValue = 0;
            barChart.XAxis.MaxValue = 3;
            barChart.YAxis.Title = "";
            barChart.YAxis.MinValue = 0;
            barChart.YAxis.MaxValue = 100;

            barChart.ShowLegend = true;
            barChart.LegendHorizontalAlignment = MindFusion.Charting.Components.LayoutAlignment.Near;
            barChart.LegendVerticalAlignment = MindFusion.Charting.Components.LayoutAlignment.Near;

            barChart.Theme = new Theme();
            barChart.Theme.CommonSeriesFills = GetBarFills();
            barChart.Theme.CommonSeriesStrokes = GetBarFills();
            barChart.GridType = GridType.Horizontal;
            barChart.Theme.GridColor1 = Color.White;
            barChart.Theme.GridColor2 = Color.FromRgb(240, 240, 240);
            barChart.Theme.GridLineColor = Color.FromRgb(192, 192, 192);
            barChart.Theme.DataLabelsBrush = new SolidBrush(Color.FromRgb(100, 100, 100));
            barChart.Theme.AxisLabelsBrush = new SolidBrush(Color.FromRgb(100, 100, 100));
            barChart.Theme.AxisTitleBrush = new SolidBrush(Color.FromRgb(100, 100, 100));
            barChart.Theme.AxisStroke = new SolidBrush(Color.FromRgb(100, 100, 100));
            barChart.Theme.DataLabelsFontSize = 12;
            barChart.Theme.AxisLabelsFontSize = 12;
            barChart.Theme.AxisTitleFontSize = 14;
            barChart.Theme.LegendBackground = new SolidBrush(Color.FromRgb(240, 240, 240));
            barChart.Theme.LegendBorderStroke = new SolidBrush(Color.FromRgb(100, 100, 100));
            barChart.Theme.LegendTitleBrush = new SolidBrush(Color.FromRgb(100, 100, 100));

            // PieChart
            pieChart.Series = new PieSeries(
                new double[] { 20, 60, 40, 55 },
                new string[] { "January", "February", "March", "April" },
                new string[] { "January", "February", "March", "April" })
            { Title = "Pie Series" };
            pieChart.Title = "Pie Chart";
            pieChart.BackgroundColor = Colors.WhiteSmoke;

            pieChart.AllowZoom = true;
            pieChart.AllowRotate = true;

            pieChart.ShowLegend = false;
            pieChart.ShowDataLabels = LabelKinds.OuterLabel;

            pieChart.Theme = new Theme();
            pieChart.Theme.SeriesFills = GetPieFills();
            pieChart.Theme.UniformSeriesStroke = new SolidBrush(Color.FromRgb(240, 240, 240));
            pieChart.Theme.SeriesStrokeThicknesses = new List<List<double>>() { new List<double>() { 15 } };
            pieChart.Theme.HighlightStroke = new SolidBrush(Color.FromRgb(224, 233, 233));
            pieChart.Theme.HighlightStrokeThickness = 10;
            pieChart.Theme.DataLabelsBrush = new SolidBrush(Color.FromRgb(100, 100, 100));
            pieChart.Theme.DataLabelsFontSize = 12;
        }

        ObservableCollection<Series> GetSeriesCollection()
        {
            ObservableCollection<Series> collection = new ObservableCollection<Series>();
            for (int i = 0; i < 3; i++)
            {
                if (i == 0)
                {
                    collection.Add(new Series2D(new double[] { 0, 1, 2, 3 },
                        new double[] { 20, 60, 40, 55 },
                        new string[] { "January", "February", "March", "April" })
                    { Title = "Series 1" });
                }
                if (i == 1)
                {
                    collection.Add(new Series2D(new double[] { 0, 1, 2, 3 },
                       new double[] { 30, 70, 65, 19 },
                       new string[] { "May", "June", "July", "August" })
                    { Title = "Series 2" });
                }
                if (i == 2)
                {
                    collection.Add(new Series2D(new double[] { 0, 1, 2, 3 },
                       new double[] { 22, 44, 33, 66 },
                       new string[] { "September", "October", "November", "December" })
                    { Title = "Series 3" });
                }
            }
            return collection;
        }

        List<Brush> GetBarFills()
        {
            var fills = new List<Brush>();

            fills.Add(new SolidBrush(Color.FromRgb(102, 154, 204)));
            fills.Add(new SolidBrush(Color.FromRgb(206, 0, 0)));
            fills.Add(new SolidBrush(Color.FromRgb(0, 52, 102)));

            return fills;
        }

        List<List<Brush>> GetPieFills()
        {
            var fills = new List<List<Brush>>();

            fills.Add(new List<Brush>() {
                new SolidBrush(Color.FromRgb(90, 121, 165)),
                new SolidBrush(Color.FromRgb(192, 192, 192)),
                new SolidBrush(Color.FromRgb(206, 0, 0)),
                new SolidBrush(Color.FromRgb(45, 57, 86))              
            });

            return fills;
        }

        void button1_Click(object sender, EventArgs e)
        {
            barChart.ResetZoom();
        }
    }
}